@@ -1,22 +1,27 @@
 package Log::ger::LogException;
 
 our $DATE = '2018-03-05'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Log::ger;
+use Eval::Util qw(inside_eval);
 
 my $prev_die_handler  = $SIG{__DIE__};
 my $prev_warn_handler = $SIG{__WARN__};
 
 $SIG{__DIE__} = sub {
     my ($msg) = @_;
-    chomp $msg;
-    log_fatal "die(): $msg";
+
+    unless (inside_eval()) {
+        chomp $msg;
+        log_fatal "die(): $msg";
+    }
     if ($prev_die_handler) { goto &$prev_die_handler } else { die @_ }
 };
 
 $SIG{__WARN__} = sub {
     my ($msg) = @_;
+
     chomp $msg;
     log_warn "warn(): $msg";
     if ($prev_warn_handler) { goto &$prev_warn_handler } else { warn @_ }
@@ -37,7 +42,7 @@ Log::ger::LogException - Log warn()/die()
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
